@@ -69,6 +69,7 @@ from asposeslidescloud.models.fill_overlay_effect import FillOverlayEffect
 from asposeslidescloud.models.font_data import FontData
 from asposeslidescloud.models.font_fallback_rule import FontFallbackRule
 from asposeslidescloud.models.font_set import FontSet
+from asposeslidescloud.models.font_subst_rule import FontSubstRule
 from asposeslidescloud.models.fonts_data import FontsData
 from asposeslidescloud.models.geometry_path import GeometryPath
 from asposeslidescloud.models.geometry_paths import GeometryPaths
@@ -229,6 +230,7 @@ from asposeslidescloud.models.slide_comment import SlideComment
 from asposeslidescloud.models.slide_comments import SlideComments
 from asposeslidescloud.models.slide_modern_comment import SlideModernComment
 from asposeslidescloud.models.slide_properties import SlideProperties
+from asposeslidescloud.models.slide_show_properties import SlideShowProperties
 from asposeslidescloud.models.slides import Slides
 from asposeslidescloud.models.solid_fill import SolidFill
 from asposeslidescloud.models.split_document_result import SplitDocumentResult
