@@ -54,7 +54,6 @@ class AudioFrame(GeometryShape):
         'x': 'float',
         'y': 'float',
         'z_order_position': 'int',
-        'shapes': 'ResourceUri',
         'fill_format': 'FillFormat',
         'effect_format': 'EffectFormat',
         'three_d_format': 'ThreeDFormat',
@@ -74,7 +73,8 @@ class AudioFrame(GeometryShape):
         'volume': 'str',
         'base64_data': 'str',
         'play_across_slides': 'bool',
-        'rewind_audio': 'bool'
+        'rewind_audio': 'bool',
+        'picture_fill_format': 'PictureFill'
     }
 
     attribute_map = {
@@ -89,7 +89,6 @@ class AudioFrame(GeometryShape):
         'x': 'x',
         'y': 'y',
         'z_order_position': 'zOrderPosition',
-        'shapes': 'shapes',
         'fill_format': 'fillFormat',
         'effect_format': 'effectFormat',
         'three_d_format': 'threeDFormat',
@@ -109,16 +108,17 @@ class AudioFrame(GeometryShape):
         'volume': 'volume',
         'base64_data': 'base64Data',
         'play_across_slides': 'playAcrossSlides',
-        'rewind_audio': 'rewindAudio'
+        'rewind_audio': 'rewindAudio',
+        'picture_fill_format': 'pictureFillFormat'
     }
 
     type_determiners = {
         'type': 'AudioFrame',
     }
 
-    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, three_d_format=None, line_format=None, hyperlink_click=None, hyperlink_mouse_over=None, type='AudioFrame', shape_type=None, audio_cd_end_track=None, audio_cd_end_track_time=None, audio_cd_start_track=None, audio_cd_start_track_time=None, embedded=None, hide_at_showing=None, play_loop_mode=None, play_mode=None, volume=None, base64_data=None, play_across_slides=None, rewind_audio=None):  # noqa: E501
+    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, fill_format=None, effect_format=None, three_d_format=None, line_format=None, hyperlink_click=None, hyperlink_mouse_over=None, type='AudioFrame', shape_type=None, audio_cd_end_track=None, audio_cd_end_track_time=None, audio_cd_start_track=None, audio_cd_start_track_time=None, embedded=None, hide_at_showing=None, play_loop_mode=None, play_mode=None, volume=None, base64_data=None, play_across_slides=None, rewind_audio=None, picture_fill_format=None):  # noqa: E501
         """AudioFrame - a model defined in Swagger"""  # noqa: E501
-        super(AudioFrame, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, three_d_format, line_format, hyperlink_click, hyperlink_mouse_over, type, shape_type)
+        super(AudioFrame, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, fill_format, effect_format, three_d_format, line_format, hyperlink_click, hyperlink_mouse_over, type, shape_type)
 
         self._audio_cd_end_track = None
         self._audio_cd_end_track_time = None
@@ -132,6 +132,7 @@ class AudioFrame(GeometryShape):
         self._base64_data = None
         self._play_across_slides = None
         self._rewind_audio = None
+        self._picture_fill_format = None
         self.type = 'AudioFrame'
 
         if audio_cd_end_track is not None:
@@ -158,6 +159,8 @@ class AudioFrame(GeometryShape):
             self.play_across_slides = play_across_slides
         if rewind_audio is not None:
             self.rewind_audio = rewind_audio
+        if picture_fill_format is not None:
+            self.picture_fill_format = picture_fill_format
 
     @property
     def audio_cd_end_track(self):
@@ -455,6 +458,28 @@ class AudioFrame(GeometryShape):
         """
         self._rewind_audio = rewind_audio
 
+    @property
+    def picture_fill_format(self):
+        """Gets the picture_fill_format of this AudioFrame.  # noqa: E501
+
+        Picture fill format.  # noqa: E501
+
+        :return: The picture_fill_format of this AudioFrame.  # noqa: E501
+        :rtype: PictureFill
+        """
+        return self._picture_fill_format
+
+    @picture_fill_format.setter
+    def picture_fill_format(self, picture_fill_format):
+        """Sets the picture_fill_format of this AudioFrame.
+
+        Picture fill format.  # noqa: E501
+
+        :param picture_fill_format: The picture_fill_format of this AudioFrame.  # noqa: E501
+        :type: PictureFill
+        """
+        self._picture_fill_format = picture_fill_format
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
