@@ -45,6 +45,7 @@ class GifExportOptions(ImageExportOptionsBase):
     swagger_types = {
         'default_regular_font': 'str',
         'font_fallback_rules': 'list[FontFallbackRule]',
+        'font_subst_rules': 'list[FontSubstRule]',
         'format': 'str',
         'height': 'int',
         'width': 'int',
@@ -56,6 +57,7 @@ class GifExportOptions(ImageExportOptionsBase):
     attribute_map = {
         'default_regular_font': 'defaultRegularFont',
         'font_fallback_rules': 'fontFallbackRules',
+        'font_subst_rules': 'fontSubstRules',
         'format': 'format',
         'height': 'height',
         'width': 'width',
@@ -68,9 +70,9 @@ class GifExportOptions(ImageExportOptionsBase):
         'format': 'gif',
     }
 
-    def __init__(self, default_regular_font=None, font_fallback_rules=None, format='gif', height=None, width=None, export_hidden_slides=None, transition_fps=None, default_delay=None):  # noqa: E501
+    def __init__(self, default_regular_font=None, font_fallback_rules=None, font_subst_rules=None, format='gif', height=None, width=None, export_hidden_slides=None, transition_fps=None, default_delay=None):  # noqa: E501
         """GifExportOptions - a model defined in Swagger"""  # noqa: E501
-        super(GifExportOptions, self).__init__(default_regular_font, font_fallback_rules, format, height, width)
+        super(GifExportOptions, self).__init__(default_regular_font, font_fallback_rules, font_subst_rules, format, height, width)
 
         self._export_hidden_slides = None
         self._transition_fps = None
