@@ -72,7 +72,10 @@ class Portion(ResourceBase):
         'underline_fill_format': 'FillFormat',
         'underline_line_format': 'LineFormat',
         'hyperlink_click': 'Hyperlink',
-        'hyperlink_mouse_over': 'Hyperlink'
+        'hyperlink_mouse_over': 'Hyperlink',
+        'latin_font': 'str',
+        'east_asian_font': 'str',
+        'complex_script_font': 'str'
     }
 
     attribute_map = {
@@ -105,13 +108,16 @@ class Portion(ResourceBase):
         'underline_fill_format': 'underlineFillFormat',
         'underline_line_format': 'underlineLineFormat',
         'hyperlink_click': 'hyperlinkClick',
-        'hyperlink_mouse_over': 'hyperlinkMouseOver'
+        'hyperlink_mouse_over': 'hyperlinkMouseOver',
+        'latin_font': 'latinFont',
+        'east_asian_font': 'eastAsianFont',
+        'complex_script_font': 'complexScriptFont'
     }
 
     type_determiners = {
     }
 
-    def __init__(self, self_uri=None, alternate_links=None, text=None, math_paragraph=None, font_bold=None, font_italic=None, font_underline=None, strikethrough_type=None, text_cap_type=None, escapement=None, spacing=None, font_color=None, highlight_color=None, font_height=None, normalise_height=None, proof_disabled=None, smart_tag_clean=None, kerning_minimal_size=None, kumimoji=None, language_id=None, alternative_language_id=None, is_hard_underline_fill=None, is_hard_underline_line=None, fill_format=None, effect_format=None, line_format=None, underline_fill_format=None, underline_line_format=None, hyperlink_click=None, hyperlink_mouse_over=None):  # noqa: E501
+    def __init__(self, self_uri=None, alternate_links=None, text=None, math_paragraph=None, font_bold=None, font_italic=None, font_underline=None, strikethrough_type=None, text_cap_type=None, escapement=None, spacing=None, font_color=None, highlight_color=None, font_height=None, normalise_height=None, proof_disabled=None, smart_tag_clean=None, kerning_minimal_size=None, kumimoji=None, language_id=None, alternative_language_id=None, is_hard_underline_fill=None, is_hard_underline_line=None, fill_format=None, effect_format=None, line_format=None, underline_fill_format=None, underline_line_format=None, hyperlink_click=None, hyperlink_mouse_over=None, latin_font=None, east_asian_font=None, complex_script_font=None):  # noqa: E501
         """Portion - a model defined in Swagger"""  # noqa: E501
         super(Portion, self).__init__(self_uri, alternate_links)
 
@@ -143,6 +149,9 @@ class Portion(ResourceBase):
         self._underline_line_format = None
         self._hyperlink_click = None
         self._hyperlink_mouse_over = None
+        self._latin_font = None
+        self._east_asian_font = None
+        self._complex_script_font = None
 
         if text is not None:
             self.text = text
@@ -200,6 +209,12 @@ class Portion(ResourceBase):
             self.hyperlink_click = hyperlink_click
         if hyperlink_mouse_over is not None:
             self.hyperlink_mouse_over = hyperlink_mouse_over
+        if latin_font is not None:
+            self.latin_font = latin_font
+        if east_asian_font is not None:
+            self.east_asian_font = east_asian_font
+        if complex_script_font is not None:
+            self.complex_script_font = complex_script_font
 
     @property
     def text(self):
@@ -977,6 +992,72 @@ class Portion(ResourceBase):
         """
         self._hyperlink_mouse_over = hyperlink_mouse_over
 
+    @property
+    def latin_font(self):
+        """Gets the latin_font of this Portion.  # noqa: E501
+
+        Returns or sets the Latin font info.  # noqa: E501
+
+        :return: The latin_font of this Portion.  # noqa: E501
+        :rtype: str
+        """
+        return self._latin_font
+
+    @latin_font.setter
+    def latin_font(self, latin_font):
+        """Sets the latin_font of this Portion.
+
+        Returns or sets the Latin font info.  # noqa: E501
+
+        :param latin_font: The latin_font of this Portion.  # noqa: E501
+        :type: str
+        """
+        self._latin_font = latin_font
+
+    @property
+    def east_asian_font(self):
+        """Gets the east_asian_font of this Portion.  # noqa: E501
+
+        Returns or sets the East Asian font info.  # noqa: E501
+
+        :return: The east_asian_font of this Portion.  # noqa: E501
+        :rtype: str
+        """
+        return self._east_asian_font
+
+    @east_asian_font.setter
+    def east_asian_font(self, east_asian_font):
+        """Sets the east_asian_font of this Portion.
+
+        Returns or sets the East Asian font info.  # noqa: E501
+
+        :param east_asian_font: The east_asian_font of this Portion.  # noqa: E501
+        :type: str
+        """
+        self._east_asian_font = east_asian_font
+
+    @property
+    def complex_script_font(self):
+        """Gets the complex_script_font of this Portion.  # noqa: E501
+
+        Returns or sets the complex script font info.  # noqa: E501
+
+        :return: The complex_script_font of this Portion.  # noqa: E501
+        :rtype: str
+        """
+        return self._complex_script_font
+
+    @complex_script_font.setter
+    def complex_script_font(self, complex_script_font):
+        """Sets the complex_script_font of this Portion.
+
+        Returns or sets the complex script font info.  # noqa: E501
+
+        :param complex_script_font: The complex_script_font of this Portion.  # noqa: E501
+        :type: str
+        """
+        self._complex_script_font = complex_script_font
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
