@@ -43,11 +43,19 @@ class ScatterChartDataPoint(DataPoint):
                             and the value is json key in definition.
     """
     swagger_types = {
+        'fill_format': 'FillFormat',
+        'effect_format': 'EffectFormat',
+        'three_d_format': 'ThreeDFormat',
+        'line_format': 'LineFormat',
         'x_value': 'float',
         'y_value': 'float'
     }
 
     attribute_map = {
+        'fill_format': 'fillFormat',
+        'effect_format': 'effectFormat',
+        'three_d_format': 'threeDFormat',
+        'line_format': 'lineFormat',
         'x_value': 'xValue',
         'y_value': 'yValue'
     }
@@ -55,9 +63,9 @@ class ScatterChartDataPoint(DataPoint):
     type_determiners = {
     }
 
-    def __init__(self, x_value=None, y_value=None):  # noqa: E501
+    def __init__(self, fill_format=None, effect_format=None, three_d_format=None, line_format=None, x_value=None, y_value=None):  # noqa: E501
         """ScatterChartDataPoint - a model defined in Swagger"""  # noqa: E501
-        super(ScatterChartDataPoint, self).__init__()
+        super(ScatterChartDataPoint, self).__init__(fill_format, effect_format, three_d_format, line_format)
 
         self._x_value = None
         self._y_value = None
